# == Schema Information
#
# Table name: wbase_plans
#
#  id            :integer          not null, primary key
#  name          :string           not null
#  stripe_id     :string           not null
#  price         :integer          not null
#  interval      :string           default("monthly")
#  features      :text
#  highlight     :boolean          default(FALSE)
#  display_order :integer          default(0)
#  created_at    :datetime         not null
#  updated_at    :datetime         not null
#
# Indexes
#
#  index_wbase_plans_on_name       (name)
#  index_wbase_plans_on_stripe_id  (stripe_id)
#

module Wbase
  class Plan < ActiveRecord::Base
    has_many :subscriptions

    def self.monthly
      where("interval LIKE '%month%'")
    end

    def self.annual
      where("interval LIKE '%yearly%'")
    end

    def display_name
      "#{ price }/#{ interval }"
    end

    def monthly?
      interval.include?('month')
    end

    def annual?
      interval.include?('year')
    end
  end
end
