# == Schema Information
#
# Table name: wbase_stripe_webhooks
#
#  id               :integer          not null, primary key
#  external_id      :string
#  object           :string
#  api_version      :string
#  created          :datetime
#  data             :json
#  livemode         :boolean
#  pending_webhooks :integer
#  external_type    :string
#  external_request :string
#  created_at       :datetime         not null
#  updated_at       :datetime         not null
#

module Wbase
  class StripeWebhook < ActiveRecord::Base
    enum state: { fresh: 0, processing: 1, processed: 2, failed: 3 }

    def process!
      self.update(state: 1)
      begin
        if external_type == 'customer.subscription.updated'
          subscription = Subscription.find_by(stripe_id: customer_stripe_id)
          subscription.update(paid_thru: Time.at(paid_thru))
        end

        self.update(state: 2)
      rescue => e
        self.update(state: 3, error_text: e)
      end
    end

    def customer_stripe_id
      get("customer")
    end

    def paid_thru
      data.fetch("object", {}).fetch("current_period_end")
    end

    def get(key)
      data.fetch("object", {}).fetch(key)
    end
  end
end
